summary refs log tree commit diff stats
path: root/src/fe-gtk/menu.c
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-10-30 11:35:39 +0100
committerBerke Viktor <bviktor@hexchat.org>2012-10-30 11:35:39 +0100
commita51a69134b8bdc94cfb4dcc1403e33cce24d34bc (patch)
treea257e588c8d13d8d275450b8903c924145e5835f /src/fe-gtk/menu.c
parent82936df2af3993c2e234042c450e0e9630b045d4 (diff)
Nah, even more rebranding
Diffstat (limited to 'src/fe-gtk/menu.c')
-rw-r--r--src/fe-gtk/menu.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/fe-gtk/menu.c b/src/fe-gtk/menu.c
index 572335ab..c649a76a 100644
--- a/src/fe-gtk/menu.c
+++ b/src/fe-gtk/menu.c
@@ -113,7 +113,7 @@ static void
 nick_command (session * sess, char *cmd)
 {
 	if (*cmd == '!')
-		xchat_exec (cmd + 1);
+		hexchat_exec (cmd + 1);
 	else
 		handle_command (sess, cmd, TRUE);
 }
@@ -516,7 +516,7 @@ menu_create (GtkWidget *menu, GSList *list, char *target, int check_path)
 		{
 			char *icon, *label;
 
 			/* default command in xchat.c */
 			if (pop->cmd[0] == 'n' && !strcmp (pop->cmd, "notify -n ASK %s"))
 			{
 				/* don't create this item if already in notify list */
@@ -1393,7 +1393,7 @@ menu_pluginlist (void)
 									"%m  =  machine info\n"\
                            "%n  =  your nick\n"\
 									"%t  =  time/date\n"\
-                           "%v  =  xchat version\n"\
+                           "%v  =  HexChat version\n"\
                            "%2  =  word 2\n"\
                            "%3  =  word 3\n"\
                            "&2  =  word 2 to the end of line\n"\
@@ -1438,7 +1438,7 @@ menu_pluginlist (void)
                            "%s  =  the URL string\n\n"\
                            "Putting a ! infront of the command\n"\
                            "indicates it should be sent to a\n"\
-                           "shell instead of XChat")
+                           "shell instead of HexChat")
 
 static void
 menu_usercommands (void)
@@ -516,7 +516,7 @@ menu_create (GtkWidget *menu, GSList *list, char *target, int check_path)
 			char *icon, *label;
 
-			/* default command in xchat.c */
+			/* default command in hexchat.c */
 			if (pop->cmd[0] == 'n' && !strcmp (pop->cmd, "notify -n ASK %s"))
 			{